OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Просмотр изображений",
    "Simple file viewer with slideshow for media" : "Простое приложение для просмотра файлов изображений и видео  с поддержкой функции слайд-шоу",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Вы можете показать свои последние праздничные фотографии и видео, прямо как в фильмах! Вы можете показать свой последний роман прямо из вашего Nextcloud! Вы можете выбрать лучший GIF из вашей коллекции благодаря непосредственному предварительному просмотру ваших избранных файлов и многое другое!",
    "Your browser does not support audio." : "Ваш браузер не поддерживает звук.",
    "Error loading {name}" : "Ошибка при загрузке {name}",
    "Unsaved changes" : "Несохранённые изменения",
    "Your browser does not support videos." : "Используемый браузер не поддерживает воспроизведение видео.",
    "Edit" : "Редактировать",
    "Open sidebar" : "Открыть боковую панель",
    "Download" : "Скачать",
    "Delete" : "Удалить",
    "There is no plugin available to display this file type" : "Нет доступного плагина для отображения этого типа файла",
    "View" : "Просмотр",
    "Name" : "Имя",
    "Save" : "Сохранить",
    "Back" : "Назад",
    "Loading …" : "Загрузка …",
    "Reset" : "Сброс",
    "Cancel" : "Отменить",
    "Continue" : "Продолжить",
    "Undo" : "Отменить",
    "Redo" : "Повторить",
    "Zoom in" : "Приблизить",
    "Original" : "Оригинал",
    "Custom" : "Свои параметры",
    "Landscape" : "Ландшафт",
    "Portrait" : "Портрет",
    "Value" : "Значение",
    "Image" : "Изображение",
    "Line" : "Линия",
    "Text" : "Текст",
    "Size" : "Размер",
    "Position" : "Должность",
    "Extension" : "Расширение",
    "Name is required." : "Необходимо указать имя.",
    "Quality" : "Качество"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
